# Changelog

<!--next-version-placeholder-->

## v3.0.0 (2021-11-12)
### Breaking
* <breaking change summary> ([`234c45f`](https://gitlab.com/jonkragskow/xyz_py/-/commit/234c45fd29e50fdb424fa6bbd428262523574dad))

### Documentation
* Update module level docstrings ([`08582a7`](https://gitlab.com/jonkragskow/xyz_py/-/commit/08582a757105b06b4657e2c43023dfab42203213))
* Add docstring to each file ([`2e9f75b`](https://gitlab.com/jonkragskow/xyz_py/-/commit/2e9f75b33c81b514dda8a97ee55a2fa430793f8b))

## v2.2.1 (2021-11-11)


## v2.2.0 (2021-11-11)
### Feature
* Add label indexing to load_xyz ([`5e4134f`](https://gitlab.com/jonkragskow/xyz_py/-/commit/5e4134f15ed9457bc148f50f093f191dc82f88eb))

## v2.1.0 (2021-11-09)
### Feature
* Add command line interface ([`40a22bb`](https://gitlab.com/jonkragskow/xyz_py/-/commit/40a22bbd6f5f3514bb5145ada9fae9a81793d9e6))

## v2.0.0 (2021-11-09)


## v1.0.0 (2021-11-09)

